package com.yidianling.user.mine

import android.annotation.SuppressLint
import android.text.Spannable
import android.text.SpannableString
import android.text.style.ForegroundColorSpan
import android.view.View
import android.view.animation.Animation
import android.view.animation.AnimationUtils
import android.widget.ImageView
import android.widget.TextView
import com.alibaba.android.arouter.launcher.ARouter
import com.ydl.ydlcommon.base.BaseActivity
import com.ydl.ydlcommon.bean.StatusBarOptions
import com.ydl.ydlcommon.data.http.BaseAPIResponse
import com.ydl.ydlcommon.modular.findRouteService
import com.ydl.ydlcommon.view.DeleteEditTextView
import com.ydl.ydlcommon.view.TitleBar
import com.yidianling.common.tools.RxImageTool
import com.yidianling.common.tools.ToastUtil
import com.yidianling.im.api.service.IImService
import com.yidianling.user.R
import com.yidianling.user.api.service.IUserService
import com.yidianling.user.http.UserHttpImpl
import com.yidianling.user.http.UserHttpImpl.Companion.getInstance
import com.yidianling.user.http.request.ModifyBaseInfo
import com.yidianling.user.http.request.UserModifyAuditRespDto
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers

/**
 * 昵称修改
 * 简介修改
 */
const val NICKNAME = 1
const val INTRODUCTION = 2

class ModifyInfoActivity : BaseActivity() {
    override fun getStatusViewOptions(): StatusBarOptions {
        return StatusBarOptions(isAddStatusView = true, statusBarDarkMode = true)
    }

    private val mShake: Animation by lazy {
        AnimationUtils.loadAnimation(this, R.anim.user_mine_shake)
    }

    private lateinit var det_set_info: DeleteEditTextView
    private lateinit var tv_tip1: TextView
    private lateinit var tv_tip2: TextView
    private lateinit var tb_title_bar: TitleBar
    private lateinit var iv_warn: ImageView

    override fun layoutResId(): Int = R.layout.user_mine_activity_set_info

    private fun findView() {
        det_set_info = findViewById(R.id.det_set_info)
        tv_tip1 = findViewById(R.id.tv_tip1)
        tv_tip2 = findViewById(R.id.tv_tip2)
        tb_title_bar = findViewById(R.id.tb_title_bar)
        iv_warn = findViewById(R.id.iv_warn)
    }

    @SuppressLint("SetTextI18n")
    override fun initDataAndEvent() {
        findView()
        val from = intent.getIntExtra("from", 0)
        if (INTRODUCTION == from) {
            det_set_info.layoutParams.height = RxImageTool.dp2px(180f)
        }
        val userInfo = findRouteService(IUserService::class.java).getUserInfo()
        det_set_info.setText(userInfo?.nick_name)
        mDisposable.add(
            getInstance().getUserAuditInfo(ModifyBaseInfo(null, if (NICKNAME == from) 101 else 103))
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe { response: BaseAPIResponse<UserModifyAuditRespDto> ->
                    if (response.code != "200") return@subscribe
                    val (_, auditStatus, _, _, _, _, _, last7Day, modifyAfter) = response.data
                    if (NICKNAME == from) {
                        if (last7Day) { // 7天内
                            tv_tip1.text = "抱歉，七天内只能修改一次昵称"
                            tv_tip1.visibility = View.VISIBLE
                            tb_title_bar.setRightTextEnable(false)
                            tb_title_bar.setRightTextColor(resources.getColor(R.color.color_9d9ea7))
                            det_set_info.setTextColor(resources.getColor(R.color.color_9d9ea7))
                            when (auditStatus) {
                                1 -> { // 审核中
                                    det_set_info.keyListener = null
                                    det_set_info.setOnClickListener {
                                        ToastUtil.toastShort(
                                            "昵称审核中，预计24小时内审核完成"
                                        )
                                    }
                                    det_set_info.setText(modifyAfter)
                                    tv_tip2.visibility = View.VISIBLE
                                    tv_tip2.text = "昵称审核中，预计24小时内审核完成，暂无法修改。"
                                }
                                2 -> { // 审核失败
                                    det_set_info.isEnabled = false
                                    tv_tip2.visibility = View.VISIBLE
                                    iv_warn.visibility = View.VISIBLE
                                    val ss = SpannableString("审核失败 ，昵称中含有违规文字。如有疑问联系客服小壹")
                                    ss.setSpan(
                                        ForegroundColorSpan(resources.getColor(R.color.color_1DA1F2)),
                                        22,
                                        ss.length,
                                        Spannable.SPAN_EXCLUSIVE_EXCLUSIVE
                                    )
                                    tv_tip2.text = ss
                                    tv_tip2.setOnClickListener {
                                        ARouter.getInstance().navigation(
                                            IImService::class.java
                                        ).startKefuChat(this, "", 0, 0)
                                    }
                                }
                                else -> { // 3: 审核成功
                                    det_set_info.keyListener = null
                                    det_set_info.setOnClickListener {
                                        ToastUtil.toastShort(
                                            "抱歉，七天内只能修改一次"
                                        )
                                    }
                                    det_set_info.setText(modifyAfter)
                                    tv_tip2.visibility = View.GONE
                                    userInfo?.nick_name = modifyAfter
                                }
                            }
                        } else {
                            tv_tip1.text = "七天内可修改一次昵称"
                            tb_title_bar.setRightTextColor(resources.getColor(R.color.color_1DA1F2))
                            tb_title_bar.setOnRightTextClick { _: View?, _: Boolean ->
                                if (checkInput()) {
                                    mDisposable.add(
                                        getInstance().modifyUserBaseInfo(
                                            ModifyBaseInfo(
                                                det_set_info.text.toString(),
                                                101
                                            )
                                        )
                                            .subscribeOn(Schedulers.io())
                                            .observeOn(AndroidSchedulers.mainThread())
                                            .subscribe {
                                                ToastUtil.toastShort("提交成功，昵称审核中，预计24小时内审核完成")
                                                setResult(RESULT_OK, intent)
                                                finish()
                                            }
                                    )
                                }
                            }
                        }
                    } else if (INTRODUCTION == from) {

                    }
                })
    }

    private fun checkInput(): Boolean {
        if (det_set_info.text.isEmpty()) {
            ToastUtil.toastShort("请输入昵称")
            det_set_info.startAnimation(mShake)
            return false
        }
        if (det_set_info.text.length > 6) {
            ToastUtil.toastShort("昵称最多6个字哦")
            det_set_info.startAnimation(mShake)
            return false
        }
        return true
    }
}